@@ -1,6 +1,6 @@
 ;;; ob-tangle.el --- Extract Source Code From Org Files -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2009-2024 Free Software Foundation, Inc.
+;; Copyright (C) 2009-2025 Free Software Foundation, Inc.
 
 ;; Author: Eric Schulte
 ;; Keywords: literate programming, reproducible research
@@ -159,9 +159,10 @@ result.  The default value is `org-remove-indentation'."
   :type 'function)
 
 (defcustom org-babel-tangle-default-file-mode #o644
-  "The default mode used for tangled files, as an integer.
-The default value 420 correspands to the octal #o644, which is
-read-write permissions for the user, read-only for everyone else."
+  "The default mode, an integer value, only used when the :tangle-mode
+header argument specifies chmod-style symbolic notation.  The default
+value 420 corresponds to the octal #o644, which is read-write
+permissions for the user, read-only for everyone else."
   :group 'org-babel-tangle
   :package-version '(Org . "9.6")
   :type 'integer)
@@ -184,8 +185,7 @@ replace contents otherwise."
   :safe t)
 
 (defun org-babel-find-file-noselect-refresh (file)
-  "Find file ensuring that the latest changes on disk are
-represented in the file."
+  "Find file ensuring that the latest changes on disk are represented in the file."
   (find-file-noselect file 'nowarn)
   (with-current-buffer (get-file-buffer file)
     (revert-buffer t t t)))
@@ -228,13 +228,11 @@ Return list of the tangled file names."
              (org-babel-tangle nil target-file lang-re)))))
 
 (defun org-babel-tangle-publish (_ filename pub-dir)
-  "Tangle FILENAME and place the results in PUB-DIR."
-  (unless (file-exists-p pub-dir)
-    (make-directory pub-dir t))
-  (setq pub-dir (file-name-as-directory pub-dir))
-  ;; Rename files to avoid copying to same file when publishing to ./
-  ;; `copy-file' would throw an error when copying file to self.
-  (mapc (lambda (el) (rename-file el pub-dir t))
+  "Tangle FILENAME and copy the tangled file to PUB-DIR."
+  (require 'ox-publish)
+  (declare-function org-publish-attachment "ox-publish"
+                    (plist filename pub-dir))
+  (mapc (lambda (el) (org-publish-attachment nil el pub-dir))
         (org-babel-tangle-file filename)))
 
 ;;;###autoload
@@ -386,10 +384,10 @@ The following forms are currently recognized:
    ((integerp mode)
     (if (string-match-p "^[0-7][0-7][0-7]$" (format "%o" mode))
         mode
-      (user-error "%1$o is not a valid file mode octal. \
+      (user-error "%1$o is not a valid file mode octal.  \
 Did you give the decimal value %1$d by mistake?" mode)))
    ((not (stringp mode))
-    (error "File mode %S not recognized as a valid format." mode))
+    (error "File mode %S not recognized as a valid format" mode))
    ((string-match-p "^o0?[0-7][0-7][0-7]$" mode)
     (string-to-number (replace-regexp-in-string "^o" "" mode) 8))
    ((string-match-p "^[ugoa]*\\(?:[+=-][rwxXstugo]*\\)+\\(,[ugoa]*\\(?:[+=-][rwxXstugo]*\\)+\\)*$" mode)
@@ -400,7 +398,7 @@ Did you give the decimal value %1$d by mistake?" mode)))
                                            ",g=" (delete ?- (substring mode 3 6))
                                            ",o=" (delete ?- (substring mode 6 9)))
                                    0))
-   (t (error "File mode %S not recognized as a valid format. See `org-babel-interpret-file-mode'." mode))))
+   (t (error "File mode %S not recognized as a valid format.  See `org-babel-interpret-file-mode'" mode))))
 
 (defun org-babel-tangle-clean ()
   "Remove comments inserted by `org-babel-tangle'.
